@@ -1,8 +1,3 @@
-# $Id: /mirror/perl/Text-AutoLink/trunk/lib/Text/AutoLink/Plugin/HTTP.pm 4207 2007-10-27T13:33:47.814555Z daisuke  $
-# 
-# Copyright (c) 2006 Daisuke Maki <dmaki@cpan.org>
-# All rights reserved.
-
 package Text::AutoLink::Plugin::HTTP;
 use strict;
 use warnings;
@@ -13,7 +8,7 @@ sub process
     my $self = shift;
     my $ref  = shift;
 
-    $$ref =~ s/(https?:\/\/[A-Za-z0-9~\/._\?\&=\-%#\+:\;,\@\']+)/
+    $$ref =~ s/(https?:\/\/[A-Za-z0-9~\/._!\?\&=\-%#\+:\;,\@\']+)/
         $self->linkfy(href => $1)
     /gex;
 }
